<?php

namespace Drupal\index_now\Controller;

use Drupal\Core\Cache\CacheableResponse;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\State\StateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * API key controller.
 */
class ApiKeyController extends ControllerBase {

  /**
   * API key controller constructor.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The state service.
   */
  public function __construct(StateInterface $state) {
    $this->state = $state;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('state')
    );
  }

  /**
   * Render the API key.
   *
   * @param string $api_key
   *   A string representing the api key.
   */
  public function build(string $api_key) {
    $state_api_key = $this->state->get('index_now_api_key');

    if (empty($state_api_key) || $state_api_key !== $api_key) {
      throw new NotFoundHttpException();
    }

    $response = new CacheableResponse($api_key, Response::HTTP_OK, ['content-type' => 'text/plain']);
    $metadata = $response->getCacheableMetadata();
    $metadata->addCacheTags(['state:index_now_api_key']);

    return $response;
  }

}
